@@ -33,11 +33,11 @@ def annotate(source: str, token: "Token", back: int = 0, forward: int = 0) -> st
     row = min(token.row, len(lines) - 1)
     prev, line = lines[row - 1 : row + 1] if row > 0 else ("", lines[row])
 
-    col_start = col_end = token.col
-    if back:
-        col_start -= back
-    if forward:
-        col_end += forward
+    if not (back or forward):
+        forward = len(token.text)
+
+    col_start = token.col - back
+    col_end = token.col + forward
     col = max(0, col_start)
 
     arrows = " " * col_start + "^" * (col_end - col_start)
@@ -120,7 +120,7 @@ def scan_token(t: Tokenizer) -> None:
             t.add_token(TokenType.FOOTER_BEGIN)
         while t.peek() != "\n" and t.has_more:
             t.advance()
-        text = t.matched
+        text = t.matched.strip()
         if text:
             t.add_token(TokenType.TEXT, text)
 
@@ -196,6 +196,7 @@ class Parser:
 def changelog(p: Parser) -> ast.Changelog:
     c = ast.Changelog()
 
+    skip_newlines(p)
     if p.expect(TokenType.HASH, TokenType.TEXT):
         c.title = p.peek(1).text
 
@@ -220,7 +221,7 @@ def changelog(p: Parser) -> ast.Changelog:
         c.versions.append(v)
 
     if p.has_more:
-        raise p.error("Unprocessable text", forward=len(p.peek().text))
+        raise p.error("Unprocessable text")
 
     return c
 
@@ -228,7 +229,7 @@ def changelog(p: Parser) -> ast.Changelog:
 def text(p: Parser) -> str:
     text = ""
     while p.match({TokenType.TEXT, TokenType.NEWLINE}):
-        text += p.peek(1).text.rstrip(" \t")
+        text += p.peek(1).text
     return text.strip()
 
 
@@ -240,8 +241,8 @@ def version(p: Parser) -> Tuple[ast.Version, Token]:
     except ValueError:
         number, date = title, ""
 
-    number = number.strip("[]")
-    v = ast.Version(number=number, date=date)
+    number = number.strip().strip("[]")
+    v = ast.Version(number=number, date=date.strip())
     skip_newlines(p)
 
     while p.expect(TokenType.HASH, TokenType.HASH, TokenType.HASH, TokenType.TEXT):
@@ -270,8 +271,7 @@ def detect_wrong_title_level(p: Parser, expected: int, reason: str) -> None:
                     msg += f", but found H{level}"
                     raise p.error(msg, token, back=level)
                 else:
-                    token = p.peek(1)
-                    raise p.error(msg, token, back=len(token.text))
+                    raise p.error(msg, token=p.peek(1))
         raise p.Rollback
 
 
@@ -283,7 +283,7 @@ def changes(p: Parser) -> Tuple[ast.ChangeType, ast.Changes]:
     except AttributeError:
         msg = "Unexpected title for changes"
         hint = "Choose from " + ", ".join(f'"{t.value}"' for t in ast.ChangeType) + "."
-        raise p.error(msg, token, forward=len(title), hint=hint) from None
+        raise p.error(msg, token, hint=hint) from None
 
     skip_newlines(p)
 
